@@ -5,7 +5,7 @@ Created on Wed Apr 29 06:38:30 2020
 @author: Sara Ben Shabbat
 """
 
-class NoExistIndexError(Exception):
+class NonExistIndexError(Exception):
     def __init__(self, message):
 
         # Call the base class constructor with the parameters it needs
